changeset 4115:4aafcdc3d9e7

(Vhelp_menu_bar_map): Deleted. (menu_bar_items): Move elts for events in Vmenu_bar_final_items to end. (syms_of_keyboard): Corresponding changes.
author Richard M. Stallman <rms@gnu.org>
date Sat, 17 Jul 1993 02:10:03 +0000
parents 5746e25610f8
children 1be9089f7721
files src/keyboard.c
diffstat 1 files changed, 15 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/src/keyboard.c	Sat Jul 17 01:43:00 1993 +0000
+++ b/src/keyboard.c	Sat Jul 17 02:10:03 1993 +0000
@@ -130,8 +130,8 @@
 /* Command to run when the help character follows a prefix key.  */
 Lisp_Object Vprefix_help_command;
 
-/* Keymap for items that appear at end of menu bar.  */
-Lisp_Object Vhelp_menu_bar_map;
+/* List of items that should move to the end of the menu bar.  */
+Lisp_Object Vmenu_bar_final_items;
 
 /* Character that causes a quit.  Normally C-g.
 
@@ -3161,7 +3161,7 @@
      in the current keymaps, or nil where it is not a prefix.  */
   Lisp_Object *maps;
 
-  Lisp_Object def, tem;
+  Lisp_Object def, tem, tail;
 
   Lisp_Object result;
 
@@ -3212,7 +3212,14 @@
 	result = menu_bar_one_keymap (def, result);
     }
 
-  result = menu_bar_one_keymap (Vhelp_menu_bar_map, result);
+  for (tail = Vmenu_bar_final_items; CONSP (tail); tail = XCONS (tail)->cdr)
+    {
+      Lisp_Object elt;
+
+      elt = Fassq (XCONS (tail)->car, result);
+      if (!NILP (elt))
+	result = Fcons (elt, Fdelq (elt, result));
+    }
 
   result = Fnreverse (result);
   Vinhibit_quit = oquit;
@@ -5223,9 +5230,10 @@
     "t means menu bar, specified Lucid style, needs to be recomputed.");
   Vlucid_menu_bar_dirty_flag = Qnil;
 
-  DEFVAR_LISP ("help-menu-bar-map", &Vhelp_menu_bar_map,
-    "Keymap defining global menu items to appear at end of menu bar.");
-  Vhelp_menu_bar_map = Qnil;
+  DEFVAR_LISP ("menu-bar-final-items", &Vmenu_bar_final_items,
+    "List of menu bar items to move to the end of the menu bar.\n\
+The elements of the listare event types that may have menu bar bindings.");
+  Vmenu_bar_final_items = Qnil;
 }
 
 keys_of_keyboard ()